window.caac.eventlistener = (function () {

    var eventlistener = {};

    /**
     * 关闭app
     */
    eventlistener.exitApp = function (e) {

        navigator.app.exitApp();
    };

    /**
     * 双击返回按钮退出
     */
    eventlistener.clickExit = function (e) {

        // 取消退出动作
        e.preventDefault();

        caac.guiframe.showMessage("再次点击退出", caac.constants.messageTypes.INFORMATION);

        // 注销返回键
        document.removeEventListener("backbutton", eventlistener.clickExit);

        // 绑定退出事件
        document.addEventListener("backbutton", eventlistener.exitApp);

        // 2秒后重新注册
        var intervalID = window.setInterval(function () {

            window.clearInterval(intervalID);

            // 注销返回键
            document.removeEventListener("backbutton", eventlistener.exitApp);

            // 重新绑定返回键
            document.addEventListener("backbutton", eventlistener.clickExit);

        }, 2000);
    };

    /**
     * 点击返回按钮返回
     */
    eventlistener.clickBack = function (e) {

        // 取消退出动作
        e.preventDefault();

        // 模拟点击返回按钮
        $(".fj-back-symbol").click();
    };

    /**
     * 返回按钮作用改为返回
     */
    eventlistener.switchBack = function () {

        // 注销点击关闭
        document.removeEventListener("backbutton", eventlistener.clickExit);

        // 绑定点击返回
        document.addEventListener("backbutton", eventlistener.clickBack);
    };

    /**
     * 返回按钮作用改为双击退出
     */
    eventlistener.switchExit = function () {

        // 注销点击关闭
        document.removeEventListener("backbutton", eventlistener.clickBack);

        // 绑定点击返回
        document.addEventListener("backbutton", eventlistener.clickExit);
    };

    /**
     * 隐藏闪屏以及登录
     */
    eventlistener.splashscreenHide = function () {

        //  验证版本号
        cordova.getAppVersion.getVersionNumber().then(function (version) {

            caac.util.postSyncServerEvent(caac.constants.httpHead.URLHEAD + "login/versioncheck.act", {version: version}, function (result) {
                caac.util.doReturnValue({
                    returnValue: result,
                    success: function (data) {

                        localStorage.setItem("versionUpdate", 0);
                    },
                    error: function (data) {

                        localStorage.setItem("versionUpdate", 1);
                    }
                });
            });

        });

        var account = localStorage.getItem("account");

        if (caac.util.isNotBlank(account)) {

            // 验证登录状态
            caac.util.postSyncServerEvent(caac.constants.httpHead.URLHEAD + "login/logincheck.act", {
                account: account,
                deviceId: device.uuid,
                version: "version"
            }, function (result) {
                caac.util.doReturnValue({
                    returnValue: result,
                    success: function (data) {

                        if (data != null) {
                            localStorage.setItem("isLimit", data.bean.isLimit);
                            localStorage.setItem("isExecutive", data.isExecutive);

                            //  极光推送删除所有标签
                            window.JPush.cleanTags({sequence: 1});

                            //  极光推送设置标签
                            window.JPush.setTags({sequence: 1, tags: data.bean.tags});
                        }

                        caac.util.postSyncServerEvent(caac.constants.httpHead.URLHEAD + "msghints/getcount.act", null, function (result) {
                            caac.util.doReturnValue({
                                returnValue: result,
                                success: function (data) {

                                    localStorage.setItem("msgCount", data.msgCount);
                                    cordova.plugins.notification.badge.set(data.msgCount);

                                    caac.guiframe.switchView("home", null, null, ".fj-content-container");
                                },
                                error: function (data) {

                                }
                            });
                        });

                    },
                    error: function (data) {

                        localStorage.setItem("msgCount", 0);
                        localStorage.setItem("loginStatus", null);
                        localStorage.setItem("name", null);
                        localStorage.setItem("departmentName", null);

                        caac.guiframe.switchView("home", null, null, ".fj-content-container");
                    }
                });
            });
        } else {

            localStorage.setItem("msgCount", 0);
            localStorage.setItem("loginStatus", null);
            localStorage.setItem("name", null);
            localStorage.setItem("departmentName", null);

            caac.guiframe.switchView("home", null, null, ".fj-content-container");
        }

        //延迟splash screnn 隐藏时间,不然会有短暂的白屏出现
        setTimeout(function () {
            navigator.splashscreen.hide();
        }, 1500);
    };

    /**
     * 点击通知栏跳转到紧急事件list页面
     */
    eventlistener.onOpenNotification = function () {

        if (localStorage.getItem("loginStatus") != null && localStorage.getItem("loginStatus") === "1") {

            // 登陆成功跳转到首页
            caac.guiframe.switchView("eventlist", {eventType: 1}, null, ".fj-content-container");
        } else {

            // 未登陆，跳到登陆页面
            caac.guiframe.switchView("login", null, null, ".fj-content-container");
        }
    };

    /**
     * 增加角标
     */
    eventlistener.addBadge = function () {

        //  角标增加1
        cordova.plugins.notification.badge.increase(1);
    };

    return eventlistener;

})();



