// 声明用户界面框架对象
window.caac.guiframe = (function () {

    // 声明用户界面框架对象
    var guiframe = {};


    /** 当前默认区域信息 */
    guiframe.locale = "zh-CN";

    /**
     * 取得页面初始化参数
     * @param {String| Object} container 画面容器
     * @return {Object} 页面初始化参数
     */
    guiframe.getInitArgs = function (container) {

        // 声明页面初始化参数
        var initArgs = null;
        // 声明页面容器
        var _container = null;

        // 如果画面容器不为空
        if (caac.util.isNotEmpty(container)) {

            // 如果画面容器是字符串对象
            if (typeof(container) == "string") {

                // 取得画面容器对象
                _container = $(container);
            }
            // 如果画面容器是对象
            else {

                // 设置画面容器对象
                _container = container;
            }
        }

        // 如果页面容器存在
        if (caac.util.isNotEmpty(_container)) {

            // 取得页面初始化参数
            initArgs = _container.data(caac.constants.initArgsName);
        }

        // 返回页面初始化参数
        return initArgs;
    };


    /**
     * 取得页面回调方法
     * @param {String| Object} container 画面容器
     * @return {Function} 页面回调方法
     */
    guiframe.getCallback = function (container) {

        // 声明页面回调方法
        var callback = null;
        // 声明页面容器
        var _container = null;

        // 如果画面容器不为空
        if (caac.util.isNotEmpty(container)) {

            // 如果画面容器是字符串对象
            if (typeof(container) == "string") {

                // 取得画面容器对象
                _container = $(container);
            }
            // 如果画面容器是对象
            else {

                // 设置画面容器对象
                _container = container;
            }
        }

        // 如果页面容器存在
        if (caac.util.isNotEmpty(_container)) {

            // 取得页面回调方法
            callback = _container.data(caac.constants.callbackFunctionName);

            // 如果页面回调方法不是方法类型
            if (typeof(callback) != "function") {

                // 重置页面回调方法对象
                callback = null;
            }
        }

        // 返回页面回调方法
        return callback;
    };

    /**
     * 取得视图对象
     * @param {String} name 视图名称
     * @return {Object} 视图对象
     */
    guiframe.getView = function (name) {

        // 取得视图对象
        var view = caac.views[name];

        // 如果视图对象不存在
        if (caac.util.isEmpty(view)) {

            // 创建视图对象
            caac.views[name] = {};
            // 设置视图对象
            view = caac.views[name];
        }

        // 返回视图对象
        return view;
    };

    /**
     * 取得视图信息
     * @param {String} viewName 视图名称
     * @return {Object} 视图信息
     */
    guiframe.getViewInfo = function (viewName) {

        // 取得视图信息
        var viewInfo = caac.views[viewName];
        // 返回视图信息
        return viewInfo;
    };

    /**
     * 加载页面
     * @param {String} url 页面URL地址
     * @param {Object} container 页面容器
     * @return {Boolean} 执行结果（TRUE：页面加载成功；FALSE：页面加载失败）
     */
    guiframe.loadPage = function (url, container) {

        // 声明方法执行结果
        var result = false;

        // 如果页面URL地址不为空并且页面容器不为空
        if (caac.util.isNotBlank(url) && caac.util.isNotEmpty(container)) {

            // 声明页面内容面板
            var contentPane = contentPane = $("<div id='dv_content_panel'></div>");

            // 向服务器端发送请求
            $.ajax({

                // 声明请求类型
                type: "POST",
                // 声明同步请求
                async: false,
                // 声明需要请求的URL地址
                url: url,
                // 声明请求返回的数据类型
                dataType: "html",
                // 声明请求正常结束回调方法
                success: function (data) {

                    // 清除页面容器内容
                    container.empty();
                    container.append(contentPane);

                    // 如果页面返回数据
                    if (caac.util.isNotEmpty(data)) {

                        // 将页面容器内容设置为请求返回的数据
                        contentPane.html(data);
                        // 设置方法执行结果
                        result = true;
                    }
                    // 如果页面没有返回数据
                    else {

                        // 将页面容器内容设置为请求返回的数据
                        contentPane.html("<div class='fj-error-message'><i class='fa fa-times-circle fa-lg'></i><span>Error 404! Page Not Found.</span></div>");
                        // 设置方法执行结果
                        result = false;
                    }
                },
                // 声明请求异常结束回调方法
                error: function (xhr, ajaxOptions, thrownError) {

                    // 清除页面容器内容
                    container.empty();
                    // 添加页面内容面板
                    container.append(contentPane);

                    // 将页面容器内容设置为请求返回的数据
                    contentPane.html("<div class='fj-error-message'><i class='fa fa-times-circle fa-lg'></i><span>Error 500! Internal Server Error.</span></div>");
                    // 设置方法执行结果
                    result = false;
                }
            });
        }

        // 返回方法执行结果
        return result;
    };

    /**
     * 切换视图
     * @param {String} name 视图名称
     * @param {Object} args 视图参数
     * @param {Function} callback 视图回调方法
     * @param {Object} container 视图容器
     */
    guiframe.switchView = function (name, args, callback, container) {

        /*if (!window.navigator.onLine) {

        } else {*/

            // 取得视图信息
            var viewInfo = caac.guiframe.getViewInfo(name);

            // 如果视图信息和视图信息存在
            if (caac.util.isNotEmpty(viewInfo)) {

                // 声明视图容器
                var viewContainer = null;

                // 如果视图容器是字符串对象
                if (typeof(container) == "string") {

                    // 取得视图容器
                    viewContainer = $(container);
                }
                // 如果视图容器是对象
                else {

                    // 设置视图容器
                    viewContainer = container;
                }

                // 如果视图容器不为空
                if (caac.util.isNotEmpty(viewContainer)) {

                    // 将对话框初始化参数绑定到对话框容器中
                    viewContainer.data("initArgs", args);
                    // 将对话框回调方法绑定到对话框容器中
                    viewContainer.data("callback", callback);

                    // 取得视图URL地址
                    var url = viewInfo.page;
                    // 加载页面
                    var isLoaded = caac.guiframe.loadPage(url, viewContainer, false);

                    // 如果页面加载成功
                    if (isLoaded) {

                        // 取得页面脚本
                        var script = viewInfo.script;

                        // 如果页面脚本不为空
                        if (caac.util.isNotBlank(script)) {

                            // 取得页面脚本
                            $.getScript(script, function (response, status) {

                                // 如果成功取得页面脚本
                                if (status == "success") {

                                    // 调用打开对话框方法
                                    onViewOpened(name, args, callback, viewContainer);
                                }
                            });
                        }
                    }
                }
            }
        //}
    };


    /**
     * 显示处理遮罩
     */
    guiframe.showScreenPanel = function () {

        // 取得处理遮罩面板
        var screenPanel = $(".fj-screen-container");

        // 如果处理遮罩面板存在
        if (caac.util.isNotEmpty(screenPanel)) {

            // 如果包含“fj-hidden”样式
            if (screenPanel.hasClass("fj-hidden")) {

                // 设置遮罩面板水平余白
                var paddingHorizontal = ($(document.body).prop("clientWidth") - 160) / 2;
                // 设置遮罩面板垂直余白
                var paddingVertical = ($(document.body).prop("clientHeight") - 100) / 2;

                // 设置遮罩面板上余白
                screenPanel.css("padding-top", paddingVertical + "px");
                // 设置遮罩面板右余白
                screenPanel.css("padding-right", paddingHorizontal + "px");
                // 设置遮罩面板下余白
                screenPanel.css("padding-bottom", paddingVertical + "px");
                // 设置遮罩面板左余白
                screenPanel.css("padding-left", paddingHorizontal + "px");

                // 删除“fj-hidden”样式
                screenPanel.removeClass("fj-hidden");
            }
        }
    };

    /**
     * 隐藏处理遮罩
     */
    guiframe.hideScreenPanel = function () {

        // 取得处理遮罩面板
        var screenPanel = $(".fj-screen-container");

        // 如果处理遮罩面板存在
        if (caac.util.isNotEmpty(screenPanel)) {

            // 如果不包含“fj-hidden”样式
            if (!screenPanel.hasClass("fj-hidden")) {

                // 添加“fj-hidden”样式
                screenPanel.addClass("fj-hidden");
            }
        }
    };

    guiframe.showMessage = function (content, type) {

        /*if (type == caac.constants.messageTypes.INFORMATION) {

            plugins.toast.showWithOptions({
                message: content,
                duration: "short",
                position: "center",
                styling: {
                    opacity: 0.75,
                    backgroundColor: '#FF0000',
                    textColor: '#FFFF00',
                    textSize: 17,
                    cornerRadius: 16,
                    horizontalPadding: 20,
                    verticalPadding: 16
                }
            });

        } else if (type == caac.constants.messageTypes.WARNING) {

            plugins.toast.showWithOptions({
                message: content,
                duration: "short",
                position: "center",
                styling: {
                    opacity: 0.75,
                    backgroundColor: '#FF0000',
                    textColor: '#FFFF00',
                    textSize: 17,
                    cornerRadius: 16,
                    horizontalPadding: 20,
                    verticalPadding: 16
                }
            });

        } else if (type == caac.constants.messageTypes.ERROR) {

            plugins.toast.showWithOptions({
                message: content,
                duration: "short",
                position: "center",
                styling: {
                    opacity: 0.75,
                    backgroundColor: '#FF0000',
                    textColor: '#FFFF00',
                    textSize: 17,
                    cornerRadius: 16,
                    horizontalPadding: 20,
                    verticalPadding: 16
                }
            });

        } else if (type == caac.constants.messageTypes.SUCCESS) {

            plugins.toast.showWithOptions({
                message: content,
                duration: "short",
                position: "center",
                styling: {
                    opacity: 0.75,
                    backgroundColor: '#FF0000',
                    textColor: '#FFFF00',
                    textSize: 17,
                    cornerRadius: 16,
                    horizontalPadding: 20,
                    verticalPadding: 16
                }
            });
        }*/

        plugins.toast.showShortCenter(content);

    };

    // 返回用户界面框架对象
    return guiframe;

})();
