// 声明系统工具对象
window.caac.util = (function () {

    // 声明系统工具对象
    var utility = {};

    /**
     * 检查对象是否为空对象
     * @param {String} str 需要检查的对象
     * @return {Boolean} 检查结果（TRUE：对象为空对象；FALSE：对象不为空对象）
     */
    utility.isEmpty = function (object) {

        // 声明检查结果
        var result = false;

        // 如果对象未定义或者为空
        if (object == undefined || object == null) {

            // 设置检查结果
            result = true;
        }
        // 如果对象已经存在
        else {

            // 如果对象是数组对象
            if (object instanceof Array) {

                // 如果数组长度为0
                if (object.length == 0) {

                    // 设置检查结果
                    result = true;
                }
            }
        }

        // 返回检查结果
        return result;
    };

    /**
     * 返回两个日期之间的所有日期
     * @param {毫秒数} begin 开始时间
     * @param {毫秒数} end 结束时间
     * @return {Array} 日期数组
     */
    utility.getAllDate = function getAll(begin, end) {

        var DateArr = [];

        for (var k = begin; k <= end;) {
            DateArr.push(new Date(k));
            k = k + 24 * 60 * 60 * 1000;
        }

        return DateArr;
    };

    /**
     * 检查对象是否不为空对象
     * @param {String} str 需要检查的对象
     * @return {Boolean} 检查结果（TRUE：对象不为空对象；FALSE：对象为空对象）
     */
    utility.isNotEmpty = function (object) {

        // 声明检查结果
        var result = false;

        // 如果对象已经定义并且不为空
        if (object != undefined && object != null) {

            // 设置检查结果
            result = true;

            // 如果对象是数组对象
            if (object instanceof Array) {

                // 如果数组长度为0
                if (object.length == 0) {

                    // 设置检查结果
                    result = false;
                }
            }
        }

        // 返回检查结果
        return result;
    };

    /**
     * 检查字符串为空字符串方法
     * @param {String} str 需要检查的字符串
     * @return {Boolean} 检查结果（TRUE：字符串为空字符串；FALSE：字符串不为空字符串）
     */
    utility.isBlank = function (str) {

        // 声明检查结果
        var result = false;

        // 如果字符串未定义或者字符串为空或者字符串是空字符串
        if (str == undefined || str == null || $.trim(str) == "") {

            // 设置检查结果
            result = true;
        }

        // 返回检查结果
        return result;
    };

    /**
     * 检查字符串不为空字符串方法
     * @param {String} str 需要检查的字符串
     * @return {Boolean} 检查结果（TRUE：字符串不为空字符串；FALSE：字符串为空字符串）
     */
    utility.isNotBlank = function (str) {

        // 声明检查结果
        var result = false;

        // 如果字符串已经定义并且字符串不为空并且字符串不是空字符串
        if (str != undefined && str != null && $.trim(str) != "") {

            // 设置检查结果
            result = true;
        }

        // 返回检查结果
        return result;
    };


    /**
     * 发送服务端请求
     * @param {String} url 请求URL地址
     * @param {Object} args 请求参数
     * @param {Function} callback 请求回调方法
     */
    utility.postServerEvent = function (url, args, callback) {

        // 向服务器端发送请求
        $.ajax({

            // 声明请求类型
            type: "POST",
            url: url,
            // 声明请求参数
            data: args,
            // 声明请求返回的数据类型
            dataType: "json",
            // 声明请求正常结束回调方法
            success: function (data) {

                // 如果回调方法是方法类型
                if (callback instanceof Function) {

                    // 调用回调方法
                    callback(data);
                }
            },
            // 声明请求异常结束回调方法
            error: function (xhr, status, error) {

                // 取得处理遮罩面板
                var screenPanel = $(".fj-screen-container");

                // 如果处理遮罩面板存在
                if (caac.util.isNotEmpty(screenPanel)) {

                    // 如果不包含“fj-hidden”样式
                    if (!screenPanel.hasClass("fj-hidden")) {

                        // 添加“fj-hidden”样式
                        screenPanel.addClass("fj-hidden");
                    }
                }

                caac.guiframe.showMessage('网络连接错误，请检查网络。', caac.constants.messageTypes.ERROR);

                // 抛出错误信息
                throw error;
            }
        });

    };

    /**
     * 发送服务端同步请求
     * @param {String} url 请求URL地址
     * @param{Object} args 请求参数
     * @param {Function} callback 请求回调方法
     */
    utility.postSyncServerEvent = function (url, args, callback) {

        $.ajax({
            // 声明请求类型
            type: "POST",
            // 声明同步请求
            async: false,
            // 声明需要请求的URL地址
            url: url,
            // 声明请求参数
            data: args,
            // 声明请求返回的数据类型
            dataType: "json",
            // 声明请求正常结束回调方法
            success: function (data) {

                // 如果回调方法是方法类型
                if (callback instanceof Function) {

                    // 调用回调方法
                    callback(data);
                }
            },
            // 声明请求异常结束回调方法
            error: function (xhr, status, error) {

                // 取得处理遮罩面板
                var screenPanel = $(".fj-screen-container");

                // 如果处理遮罩面板存在
                if (caac.util.isNotEmpty(screenPanel)) {

                    // 如果不包含“fj-hidden”样式
                    if (!screenPanel.hasClass("fj-hidden")) {

                        // 添加“fj-hidden”样式
                        screenPanel.addClass("fj-hidden");
                    }
                }

                if(caac.constants.httpHead.URLHEAD + "login/logincheck.act" == url || caac.constants.httpHead.URLHEAD + "login/versioncheck.act" == url){

                    caac.guiframe.showMessage('连接失败，请检查网络，非网络原因请联系管理员。', caac.constants.messageTypes.ERROR);

                    setTimeout(function () {

                        navigator.app.exitApp();
                    }, 5000);
                } else {

                    caac.guiframe.showMessage('连接失败，请检查网络。', caac.constants.messageTypes.ERROR);
                }

                // 抛出错误信息
                throw error;
            }
        });
    };

    /**
     * 处理服务端返回值,通配符错误项目为包含
     * @param {Object} data 执行结果（returnValue：服务端返回数据；result：服务端处理结果；success：服务端处理成功方法；error：服务端处理失败方法；）
     */
    utility.doReturnValue = function (data) {

        // 如果返回值不为空
        if (caac.util.isNotEmpty(data)) {

            // 取得服务端返回数据
            var returnValue = data.returnValue.data;
            // 取得服务端处理结果
            var result = data.returnValue.result;

            // 如果处理结果不为空
            if (caac.util.isNotBlank(result)) {

                // 如果处理结果是“success”
                if (result == caac.constants.results.EXECUTION_RESULT_SUCCESS) {

                    // 取得服务端处理成功方法
                    var success = data.success;

                    // 如果服务端处理成功方法不为空并且如果服务端处理成功方法是“Function”类型
                    if (caac.util.isNotBlank(success) && (success instanceof Function)) {

                        // 执行服务端处理成功方法
                        success(returnValue);
                    }
                }
                // 如果处理结果是“error”
                else if (result == caac.constants.results.EXECUTION_RESULT_ERROR) {

                    // 取得服务端处理失败方法
                    var error = data.error;

                    // 取得错误项目
                    var errorItems = data.returnValue.errorItems;

                    // 如果错误项目不为空
                    if (caac.util.isNotEmpty(errorItems)) {

                        // 循环处理错误项目
                        for (var i = 0, nLength = errorItems.length; i < nLength; i++) {

                            // 选取错误项目
                            $("[data-bind*=" + errorItems[i] + "]").removeClass("fj-error-item").addClass("fj-error-item");
                        }
                    }

                    // 如果服务端处理失败方法不为空并且如果服务端处理失败方法是“Function”类型
                    if (caac.util.isNotBlank(error) && (error instanceof Function)) {

                        // 执行服务端处理失败方法
                        error(returnValue);
                    }
                }
            }
        }
    };

    /**
     * 处理服务端返回值,通配符错误项目为等于
     * @param {Object} data 执行结果（returnValue：服务端返回数据；result：服务端处理结果；success：服务端处理成功方法；error：服务端处理失败方法；）
     */
    utility.doReturnValue2 = function (data) {

        // 如果返回值不为空
        if (caac.util.isNotEmpty(data)) {

            // 取得服务端返回数据
            var returnValue = data.returnValue.data;
            // 取得服务端处理结果
            var result = data.returnValue.result;

            // 如果处理结果不为空
            if (caac.util.isNotBlank(result)) {

                // 如果处理结果是“success”
                if (result == caac.constants.results.EXECUTION_RESULT_SUCCESS) {

                    // 取得服务端处理成功方法
                    var success = data.success;

                    // 如果服务端处理成功方法不为空并且如果服务端处理成功方法是“Function”类型
                    if (caac.util.isNotBlank(success) && (success instanceof Function)) {

                        // 执行服务端处理成功方法
                        success(returnValue);
                    }
                }
                // 如果处理结果是“error”
                else if (result == caac.constants.results.EXECUTION_RESULT_ERROR) {

                    // 取得服务端处理失败方法
                    var error = data.error;

                    // 取得错误项目
                    var errorItems = data.returnValue.errorItems;

                    // 如果错误项目不为空
                    if (caac.util.isNotEmpty(errorItems)) {

                        // 循环处理错误项目
                        for (var i = 0, nLength = errorItems.length; i < nLength; i++) {

                            // 选取错误项目
                            $("[data-bind=" + errorItems[i] + "]").removeClass("fj-error-item").addClass("fj-error-item");
                        }
                    }

                    // 如果服务端处理失败方法不为空并且如果服务端处理失败方法是“Function”类型
                    if (caac.util.isNotBlank(error) && (error instanceof Function)) {

                        // 执行服务端处理失败方法
                        error(returnValue);
                    }
                }
            }
        }
    };

    /**
     * 将日期字符串表达式转换为日期对象
     * @param {String} value 日期字符串表达式
     * @param {Date} 日期对象
     */
    utility.convertStringToDate = function (value) {

        // 声明日期对象
        var dateValue = null;

        // 如果日期字符串表达式不为空
        if (caac.util.isNotBlank(value)) {

            // 拆分日期字符串表达式
            var sections = value.split("/");

            // 创建日期对象
            dateValue = new Date(parseInt(sections[0]), parseInt(sections[1]) - 1, parseInt(sections[2]));
        }

        // 返回日期对象
        return dateValue;
    };

    /**
     * 取得浏览器类型
     * @return {Number} 浏览器类型
     */
    utility.getNavigatorType = function () {

        // 取得浏览器用户代理信息
        var userAgent = $(navigator).prop("userAgent");

        // 声明浏览器类型
        var navigatorType = caac.constants.navigatorType.OTHER;

        // 如果浏览器是IE
        if (userAgent.indexOf("Trident") != -1) {

            // 设置浏览器类型
            navigatorType = caac.constants.navigatorType.IE;
        }
        // 如果浏览器是Edge
        else if (userAgent.indexOf("Edge") != -1) {

            // 设置浏览器类型
            navigatorType = caac.constants.navigatorType.EDGE;
        }
        // 如果浏览器是火狐
        else if (userAgent.indexOf("Firefox") != -1) {

            // 设置浏览器类型
            navigatorType = caac.constants.navigatorType.FIREFOX;
        }
        // 如果浏览器是Chrome
        else if (userAgent.indexOf("Chrome") != -1) {

            // 设置浏览器类型
            navigatorType = caac.constants.navigatorType.CHROME;
        }

        // 返回浏览器类型
        return navigatorType;
    };

    /**
     * 下载文件
     * @param {String} url 文件下载URL
     */
    utility.download = function (url) {

        // 如果文件下载URL不为空
        if (caac.util.isNotBlank(url)) {

            // 下载文件
            window.open(encodeURI(encodeURI(url)), "_blank");
        }
    };

    /**
     * 异步下载文件
     * @param {String} url 文件下载URL
     */
    utility.download = function (url, args) {
        var w = window.open('about:blank');
        // 向服务器端发送请求,先生成符合条件的excel
        $.ajax({

            // 声明请求类型
            type: "POST",
            // 声明同步请求
            async: false,
            // 声明需要请求的URL地址
            url: url,
            // 声明请求参数
            data: args,
            // 声明请求返回的数据类型
            dataType: "json",
            // 声明请求正常结束回调方法
            success: function (data) {

                var downloadUrl = "../documentpreview/download.act?filePath=" + data.data;
                // 下载文件
                w.location.href = encodeURI(encodeURI(downloadUrl));
            },
            // 声明请求异常结束回调方法
            error: function (xhr, status, error) {

            }
        });
    };

    /**
     * 导出时异步下载文件
     * @param {String} url 文件下载URL
     */
    utility.exportDownload = function (url, args) {
        // 向服务器端发送请求,先生成符合条件的excel
        $.ajax({

            // 声明请求类型
            type: "POST",
            // 声明同步请求
            async: false,
            // 声明需要请求的URL地址
            url: url,
            // 声明请求参数
            data: args,
            // 声明请求返回的数据类型
            dataType: "json",
            // 声明请求正常结束回调方法
            success: function (data) {

                var downloadUrl = "../documentpreview/exportdownload.act?filePath=" + data.data;
                // 下载文件
                window.location.href = encodeURI(encodeURI(downloadUrl));
            },
            // 声明请求异常结束回调方法
            error: function (xhr, status, error) {

            }
        });
    };

    Date.prototype.format = function (format) {
        var date = {
            "M+": this.getMonth() + 1,
            "d+": this.getDate(),
            "h+": this.getHours(),
            "m+": this.getMinutes(),
            "s+": this.getSeconds(),
            "q+": Math.floor((this.getMonth() + 3) / 3),
            "S+": this.getMilliseconds()
        };

        if (/(y+)/i.test(format)) {

            format = format.replace(RegExp.$1, (this.getFullYear() + '').substr(4 - RegExp.$1.length));
        }

        for (var k in date) {
            if (new RegExp("(" + k + ")").test(format)) {
                format = format.replace(RegExp.$1, RegExp.$1.length == 1 ? date[k] : ("00" + date[k]).substr(("" + date[k]).length));
            }

        }

        return format;
    };

    // 返回系统工具对象
    return utility;

})();