// 声明控件
window.caac.widgets = (function () {

    // 声明控件对象
    var widgets = {};

    // 声明日历控件
    widgets.calendar = {

        // 设置当前日历控件对象
        self: this,

        // 声明目标对象
        target: null,

        // 所有日程
        schedule: null,

        // 声明日期单元格后的回调方法
        callback: null,

        /*
         * 判断指定日期是否有日程
         * @param date {Date} 需要判断是否有日程的日期
         * @return {Boolean} 判断结果（TRUE：指定的日期有日程；FALSE：指定的日期没有日程）
         */
        hasSchedule: function (date) {

            // 声明判断结果
            var result = false;

            // 如果所有日程数组不为空
            if (caac.util.isNotEmpty(self.schedule)) {

                // 循环处理所有日程数组
                for (var i = 0, nLength = self.schedule.length; i < nLength; i++) {

                    // 如果指定的日期年月日都与当前日期相同
                    if (self.schedule[i].getFullYear() == date.getFullYear()
                        && self.schedule[i].getMonth() == date.getMonth()
                        && self.schedule[i].getDate() == date.getDate()) {

                        // 设置判断结果
                        result = true;
                        // 跳出循环
                        break;
                    }
                }
            }

            // 返回判断结果
            return result;
        },

        /*
         * 渲染日历控件
         * @param standard {Date} 日历控件的基准日期
         */
        render: function (standard) {

            // 清除所有日期单元格内容
            self.target.find("td").empty();
            // 解绑所有单元格单击事件
            self.target.find("td").unbind("click");

            // 取得当前日期
            var rightNow = new Date();

            // 声明月末日
            var lastDay = new Date(standard.getFullYear(), standard.getMonth(), standard.getDate());
            // 设置月末日
            lastDay = new Date(lastDay.getFullYear(), lastDay.getMonth() + 1, 0);
            // 取得本月天数
            var days = lastDay.getDate();

            // 声明星期索引
            var weekIndex = 2;
            // 声明日期对象
            var date = new Date(standard.getFullYear(), standard.getMonth(), standard.getDate());
            // 声明日历单元格内容
            var content = null;

            // 循环处理所有日期
            for (var i = 1; i <= days; i++) {

                // 设置日期对象为当前处理对象
                date.setDate(i);

                // 如果当前日期是今天
                if (rightNow.getFullYear() == date.getFullYear()
                    && rightNow.getMonth() == date.getMonth()
                    && rightNow.getDate() == date.getDate()) {

                    // 设置日历单元格内容
                    content = "<div class='fj-today fj-selected'><span>" + i + "</span><div></div></div>";
                }
                // 如果当前日是一号
                else if (date.getDate() == 1) {

                    // 设置日历单元格内容
                    content = "<div class='fj-first-date'><span>" + i + "</span><div></div></div>";
                }
                // 其余
                else {

                    // 设置日历单元格内容
                    content = "<div><span>" + i + "</span><div></div></div>";
                }

                // 取得对应的日历单元格
                var cell = self.target.find("tr:nth-child(" + weekIndex + ") td:nth-child(" + (date.getDay() + 1) + ")");
                // 设置日历单元格内容
                cell.html(content);
                // 为日历单元格绑定数据
                cell.data("date", new Date(date.getFullYear(), date.getMonth(), date.getDate()));
                // 标识日历单元格没有日程
                cell.data("hasSchedule", false);

                // 如果所有日程数组存在
                if (caac.util.isNotEmpty(self.schedule)) {

                    // 如果当前日期有日程
                    if (caac.widgets.calendar.hasSchedule(date)) {

                        // 添加日程样式
                        cell.find("div > div").addClass("has-self-event");
                        // 标识日历单元格有日程
                        cell.data("hasSchedule", true);
                    }
                }

                // 如果当前日期是星期六
                if (date.getDay() == 6) {

                    // 星期索引加1
                    weekIndex = weekIndex + 1;
                }
            }

            // 为所有日历单元格绑定单击事件
            self.target.find("td").bind("click", function (event) {

                // 查找当前已经选定的单元格
                var selectedDate = self.target.find(".fj-selected");

                // 如果当前有选定的单元格
                if (caac.util.isNotEmpty(selectedDate)) {

                    // 删除选定单元格的选定样式
                    selectedDate.removeClass("fj-selected");
                }

                // 为当前选定的单元格添加选定样式
                $(event.currentTarget).find("> div").addClass("fj-selected");

                // 如果日期单元格回调方法不为空
                if (caac.util.isNotEmpty(self.callback)) {

                    // 如果日期单元格回调方法是方法类型
                    if (typeof(self.callback) == "function") {

                        // 调用日期单元格回调方法
                        self.callback($(event.currentTarget).data("date"), $(event.currentTarget).data("hasSchedule"));
                    }
                }
            });
        },

        /*
         * 日历控件初始化方法
         * @param target {String|Object} 日历控件渲染的选择表达式或对象
         * @param schedule {Array} 所有日程数组
         * @param callback {Function} 点击日期单元格后的回调方法
         * 	[参数列表]
         * 		@param date {Date} 选中的日期
         * 		@param hasSchedule {Boolean} 选中的日期是否有日程（TRUE：有日程；FALSE：没有日程）
         */
        init: function (target, schedule, callback) {

            // 如果目标对象不为空
            if (caac.util.isNotEmpty(target)) {

                // 设置所有日程
                self.schedule = schedule;

                // 设置当前日历控件对象
                self.callback = callback;

                // 如果目标对象是字符串型
                if (typeof(target) == "string") {

                    // 选取目标对象并设置目标对象
                    self.target = $(target);
                }
                // 目标对象是其他类型
                else {

                    // 设置目标对象
                    self.target = target;
                }

                // 渲染日历控件
                caac.widgets.calendar.render(new Date());
            }
        }
    };

    // 返回控件对象
    return widgets;
})();